==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/az.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Sənədlər",
    "Can't create document" : "Sənədi yaratmaq mümkün olmadı",
    "You don't have permission to rename this document" : "Bu sənədin adını dəyişmək üçün sizin yetkiniz yoxdur.",
    "Directory saved successfully." : "Qovluq uğurla saxlanıldı.",
    "An error occurred while changing directory." : "Qovluğu dəyişdikdə səhv baş verdi.",
    "Saved" : "Saxlanıldı",
    "Format filter server is down or misconfigured" : "Fomat filtrasiyası serveri sönülüdür yada düzgün config edilməyib",
    "Conversion failed. Check log for details." : "Dəyişiklikdə səh oldu. Ətraflı məlumat üçün jurnal faylını yoxlayın",
    "Saving..." : "Saxlama...",
    "Failed to load documents." : "Sənədlərin yüklənməsi mümkün olmadı.",
    "No documents were found. Upload or create a document to get started!" : "Heç bir sənəd tapılmadı. Başlamaq üçün bir sənəd yarat yada əlavə et!",
    "No connection to server. Trying to reconnect." : "Serverə qoşulma yoxdur. Yenidən qoşulmaya cəhd elə",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Bu səhifəni dəyişdirilmə rejimində tərk etsəniz, qeyd edilməmiş datalar ola bilər. Məsləhət olunur ki, 'Close' düyməsindən istifadə edəsiniz.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Bu sənədin yüklənməsində səhv baş verdi. Xahiş olunur bunun kənar odt editorla açıla bilməsini yoxlayasınız. Həmçinin ola bilər ki, yaxın vaxtlarda ya silinib yada paylaşımı dayandırılıb.",
    "Save" : "Saxlamaq",
    "Loading documents..." : "Sənədlər yüklənir...",
    "'.' is an invalid file name." : "'.' yalnış fayl adıdır.",
    "File name cannot be empty." : "Faylın adı boş ola bilməz.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Yalnış ad, '\\', '/', '<', '>', ':', '\"', '|', '?' və '*' qəbul edilmir.",
    "Align Left" : "Sola Düzmək",
    "Alignment" : "Sıra",
    "Align Right" : "Sağa Sıralama",
    "Annotate" : "Kommentləmə",
    "Background" : "Arxada",
    "Bold" : "Qalın",
    "Bottom" : "Alt",
    "Cancel" : "Dayandır",
    "Center" : "Mərkəz",
    "Clone" : "Klon",
    "Clone this Style" : "Bu stili klonla",
    "Close" : "Bağla",
    "Color" : "Rəng",
    "Create" : "Yarat",
    "Decrease Indent" : "Böşluğu azaltmaq",
    "Default Style" : "Susmaya görə olan stil",
    "Delete" : "Sil",
    "Family" : "Ailə",
    "Font" : "Şrift",
    "Font Effects" : "Şrift Effektləri",
    "Format" : "Format",
    "Increase Indent" : "Boşluğu artırmaq",
    "Insert Image" : "Təsviri yerləşdirmək",
    "Invite Members" : "Üzvləri dəvət elə",
    "Italic" : "Kursiv",
    "Justified" : "Bəraət qazandırılmışdır",
    "Justify" : "Doğrultmaq",
    "Left" : "Sol",
    "Loading" : "Yüklənir",
    "Members" : "Üzvlər",
    "New Name:" : "Yeni ad:",
    "OK" : "Oldu",
    "Open" : "Aç",
    "Options" : "Opsiyalar",
    "Paragraph..." : "Praqraf...",
    "Paragraph Styles" : "Paraqraf stilləri",
    "Redo" : "Dəyişdirmək",
    "Right" : "Sağ",
    "Size" : "Həcm",
    "Spacing" : "Məsafə",
    "Strikethrough" : "Xətlənmiş",
    "Style" : "Stil",
    "Text" : "Tekst",
    "Top" : "Yuxarı",
    "Underline" : "Altdan cız çəkmək",
    "Undo" : "Qaytar",
    "Unknown Author" : "Naməlum Avtor",
    "Edit" : "Dəyişiklik et",
    "Share" : "Yayımla",
    "guest" : "Qonaq",
    "MS Word support (requires openOffice/libreOffice)" : "MS Word dəstəklənməsi (tələb edilir openOffice/libreOffice)",
    "Local" : "Yerli",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice bu serverə yüklənmişdir. Binar fayl üçün ünvan config.php faylında preview_libreoffice_path ilə təyin edilir ",
    "External" : "Kənar",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice kənar serverdə filter formatında yüklənmişdir",
    "Disabled" : "Dayandırılıb",
    "No MS Word support" : "MS Word dəstəyi yoxdur",
    "scheme://domain.tld[:port]" : "scheme://domain.tld[:port]",
    "Server URL" : "Server URL",
    "Apply and test" : "Mənimsət və test elə",
    "New document" : "Yeni sənəd",
    "Upload (max. %s)" : "Yüklə (max. %s)",
    "Upload" : "Serverə yüklə",
    "Save new documents to" : "Yeni sənədləri bu ünvanda saxla ",
    "Wrong password. Please retry." : "Yalnış şifrə. Xahiş olunur təkrarlayasınız.",
    "Password" : "Şifrə",
    "Guest %s" : "Qonaq %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Linkin vaxtı artıq bitmişdir və ya heç vaxt movcud olmayıb. Xahiş olunur detallar üçün bunu sizinlə paylaşan şəxs ilə əlaqə saxlayasınız.",
    "Advanced feature-set" : "Genişlənmiş imkanlar seçimi",
    "(Unstable)" : "(Qeyri stabil)"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-documents-1%3A9.1.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/az.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Sənədlər",
    "Can't create document" : "Sənədi yaratmaq mümkün olmadı",
    "You don't have permission to rename this document" : "Bu sənədin adını dəyişmək üçün sizin yetkiniz yoxdur.",
    "Directory saved successfully." : "Qovluq uğurla saxlanıldı.",
    "An error occurred while changing directory." : "Qovluğu dəyişdikdə səhv baş verdi.",
    "Saved" : "Saxlanıldı",
    "Format filter server is down or misconfigured" : "Fomat filtrasiyası serveri sönülüdür yada düzgün config edilməyib",
    "Conversion failed. Check log for details." : "Dəyişiklikdə səh oldu. Ətraflı məlumat üçün jurnal faylını yoxlayın",
    "Saving..." : "Saxlama...",
    "Failed to load documents." : "Sənədlərin yüklənməsi mümkün olmadı.",
    "No documents were found. Upload or create a document to get started!" : "Heç bir sənəd tapılmadı. Başlamaq üçün bir sənəd yarat yada əlavə et!",
    "No connection to server. Trying to reconnect." : "Serverə qoşulma yoxdur. Yenidən qoşulmaya cəhd elə",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Bu səhifəni dəyişdirilmə rejimində tərk etsəniz, qeyd edilməmiş datalar ola bilər. Məsləhət olunur ki, 'Close' düyməsindən istifadə edəsiniz.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Bu sənədin yüklənməsində səhv baş verdi. Xahiş olunur bunun kənar odt editorla açıla bilməsini yoxlayasınız. Həmçinin ola bilər ki, yaxın vaxtlarda ya silinib yada paylaşımı dayandırılıb.",
    "Save" : "Saxlamaq",
    "Loading documents..." : "Sənədlər yüklənir...",
    "'.' is an invalid file name." : "'.' yalnış fayl adıdır.",
    "File name cannot be empty." : "Faylın adı boş ola bilməz.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Yalnış ad, '\\', '/', '<', '>', ':', '\"', '|', '?' və '*' qəbul edilmir.",
    "Align Left" : "Sola Düzmək",
    "Alignment" : "Sıra",
    "Align Right" : "Sağa Sıralama",
    "Annotate" : "Kommentləmə",
    "Background" : "Arxada",
    "Bold" : "Qalın",
    "Bottom" : "Alt",
    "Cancel" : "Dayandır",
    "Center" : "Mərkəz",
    "Clone" : "Klon",
    "Clone this Style" : "Bu stili klonla",
    "Close" : "Bağla",
    "Color" : "Rəng",
    "Create" : "Yarat",
    "Decrease Indent" : "Böşluğu azaltmaq",
    "Default Style" : "Susmaya görə olan stil",
    "Delete" : "Sil",
    "Family" : "Ailə",
    "Font" : "Şrift",
    "Font Effects" : "Şrift Effektləri",
    "Format" : "Format",
    "Increase Indent" : "Boşluğu artırmaq",
    "Insert Image" : "Təsviri yerləşdirmək",
    "Invite Members" : "Üzvləri dəvət elə",
    "Italic" : "Kursiv",
    "Justified" : "Bəraət qazandırılmışdır",
    "Justify" : "Doğrultmaq",
    "Left" : "Sol",
    "Loading" : "Yüklənir",
    "Members" : "Üzvlər",
    "New Name:" : "Yeni ad:",
    "OK" : "Oldu",
    "Open" : "Aç",
    "Options" : "Opsiyalar",
    "Paragraph..." : "Praqraf...",
    "Paragraph Styles" : "Paraqraf stilləri",
    "Redo" : "Dəyişdirmək",
    "Right" : "Sağ",
    "Size" : "Həcm",
    "Spacing" : "Məsafə",
    "Strikethrough" : "Xətlənmiş",
    "Style" : "Stil",
    "Text" : "Tekst",
    "Top" : "Yuxarı",
    "Underline" : "Altdan cız çəkmək",
    "Undo" : "Qaytar",
    "Unknown Author" : "Naməlum Avtor",
    "Error" : "Səhv",
    "Share" : "Yayımla",
    "Share link" : "Linki yayımla",
    "Password" : "Şifrə",
    "Send" : "Göndər",
    "Expiration" : "Vaxtın bitməsi",
    "group" : "qrup",
    "Unshare" : "Paylaşımı durdur",
    "can share" : "yayımlaya bilərsiniz",
    "can edit" : "dəyişmək olar",
    "delete" : "sil",
    "Email sent" : "Məktub göndərildi",
    "Warning" : "Xəbərdarlıq",
    "Edit" : "Dəyişiklik et",
    "guest" : "Qonaq",
    "MS Word support (requires openOffice/libreOffice)" : "MS Word dəstəklənməsi (tələb edilir openOffice/libreOffice)",
    "Local" : "Yerli",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice bu serverə yüklənmişdir. Binar fayl üçün ünvan config.php faylında preview_libreoffice_path ilə təyin edilir ",
    "External" : "Kənar",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice kənar serverdə filter formatında yüklənmişdir",
    "Disabled" : "Dayandırılıb",
    "No MS Word support" : "MS Word dəstəyi yoxdur",
    "scheme://domain.tld[:port]" : "scheme://domain.tld[:port]",
    "Server URL" : "Server URL",
    "Apply and test" : "Mənimsət və test elə",
    "New document" : "Yeni sənəd",
    "Upload (max. %s)" : "Yüklə (max. %s)",
    "Upload" : "Serverə yüklə",
    "Save new documents to" : "Yeni sənədləri bu ünvanda saxla ",
    "Wrong password. Please retry." : "Yalnış şifrə. Xahiş olunur təkrarlayasınız.",
    "Guest %s" : "Qonaq %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Linkin vaxtı artıq bitmişdir və ya heç vaxt movcud olmayıb. Xahiş olunur detallar üçün bunu sizinlə paylaşan şəxs ilə əlaqə saxlayasınız.",
    "Advanced feature-set" : "Genişlənmiş imkanlar seçimi",
    "(Unstable)" : "(Qeyri stabil)"
},
"nplurals=2; plural=(n != 1);");
